##  Troubleshooting
The table below lists common errors that you may encounter and how to resolve them.
Errors |  Screenshot |  Potential Solution
---|---|---
When pasting the API service key, you receive the message: “This does not look like JSON config, please add a different JSON config.“ |  ![Image 2](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27534ac37a441014a2cca96ecc523ac1_LowRes.png) | Ensure the JSON is exactly as downloaded from the BTP cockpit. In this example, the values were enclosed in single quotes (') instead of the needed double quotes (").
When pasting the API service key, you receive the message: “Authentication Failed. The JSON API credentials you've provided are incorrect or not recognized. (…)“ |  ![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274429ff7a44101497df8a8689a69b0b_LowRes.png) |  Validate the service key as described in [Validating the Cloud ALM Service Key](https://help.sap.com/docs/leanix/ea/configuring-sap-cloud-alm-integration-for-managing-projects?locale=en-US&state=PRODUCTION&version=CLOUD#loio27596e0b7a441014bbe3940a5119c87b__validating_the_cloud_alm_service_key). Check if the key has expired. Check if any parts of the secret are missing. Check if necessary ‘Binding Parameters' are absent.
When enabling the SAP Cloud ALM API, you receive the message: “Your credentials are valid, but your service key does not have the necessary permissions to access the resource.” |  ![Image 2](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274782ba7a4410148c0cbd9b2fa2dfa9_LowRes.png) | Ensure you use the correct JSON code as given in the section [Enabling API Access to SAP Cloud ALM](https://help.sap.com/docs/leanix/ea/configuring-sap-cloud-alm-integration-for-managing-projects?locale=en-US&state=PRODUCTION&version=CLOUD#loio27596e0b7a441014bbe3940a5119c87b__enabling_api_access_to_sap_cloud_alm) and not the JSON code in the guide [Create or Update an Instance](https://help.sap.com/docs/cloud-alm/setup-administration/enabling-sap-cloud-alm-api#procedure "https://help.sap.com/docs/cloud-alm/setup-administration/enabling-sap-cloud-alm-api#procedure"). This ensures correct permissions are passed in the <authorities> attribute.


